# Setting Up Your Organization's S-User Administrator
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/setting-up-your-organization-s-s-user-administrator#overview)
  * [Creating Your First S-User Administrator](https://help.sap.com/docs/leanix/ea/setting-up-your-organization-s-s-user-administrator#creating-your-first-s-user-administrator)
  * [Creating Additional S-User Administrators](https://help.sap.com/docs/leanix/ea/setting-up-your-organization-s-s-user-administrator#creating-additional-s-user-administrators)


This guide describes how set up your organization’s first S-user administrator to start managing access to SAP for Me
